pub struct Carton {
    pub carton_identifiers: Option<Vec<ContainerIdentification>>,
    pub carton_sequence_number: String,
    pub dimensions: Option<Box<Dimensions>>,
    pub weight: Option<Box<Weight>>,
    pub tracking_number: Option<String>,
    pub items: Vec<ContainerItem>,
}
Carton : Details of the carton/package being shipped.

Fields

carton_identifiers: Option<Vec<ContainerIdentification>>

A list of carton identifiers.

carton_sequence_number: String

Carton sequence number for the carton. The first carton will be 001, the second 002, and so on. This number is used as a reference to refer to this carton from the pallet level.

dimensions: Option<Box<Dimensions>>weight: Option<Box<Weight>>tracking_number: Option<String>

This is required to be provided for every carton in the small parcel shipments.

items: Vec<ContainerItem>

A list of container item details.

Implementations

Details of the carton/package being shipped.